# ProxyGetPaymentMethodSnapshotCreditCardType

The type of credit card or debit card.

## Enum

* `AMERICANEXPRESS` (value: `'AmericanExpress'`)

* `DISCOVER` (value: `'Discover'`)

* `MASTERCARD` (value: `'MasterCard'`)

* `VISA` (value: `'Visa'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


